# Changelog — free/core/middleware

## 0.1.20 — Automated patch release triggered by content hash change (2026-02-14)

- chore: Automated patch release triggered by content hash change

## 0.1.19 — Automated patch release triggered by content hash change (2026-02-14)

- chore: Automated patch release triggered by content hash change

## 0.1.18 — Automated patch release triggered by content hash change (2026-02-14)

- chore: Automated patch release triggered by content hash change

## 0.1.17 — Automated patch release triggered by content hash change (2026-02-14)

- chore: Automated patch release triggered by content hash change

## 0.1.16 — Automated patch release triggered by content hash change (2026-02-14)

- chore: Automated patch release triggered by content hash change

## 0.1.15 — Automated patch release triggered by content hash change (2026-02-14)

- chore: Automated patch release triggered by content hash change

## 0.1.14 — Automated patch release triggered by content hash change (2026-02-11)

- chore: Automated patch release triggered by content hash change

## 0.1.13 — Automated patch release triggered by content hash change (2025-12-25)

- chore: Automated patch release triggered by content hash change

## 0.1.12 — Automated patch release triggered by content hash change (2025-12-14)

- chore: Automated patch release triggered by content hash change

## 0.1.11 — Automated patch release triggered by content hash change (2025-12-14)

- chore: Automated patch release triggered by content hash change

## 0.1.10 — Automated patch release triggered by content hash change (2025-12-13)

- chore: Automated patch release triggered by content hash change

## 0.1.9 — Automated patch release triggered by content hash change (2025-12-12)

- chore: Automated patch release triggered by content hash change

## 0.1.8 — Automated patch release triggered by content hash change (2025-12-12)

- chore: Automated patch release triggered by content hash change

## 0.1.7 — Automated patch release triggered by content hash change (2025-12-11)

- chore: Automated patch release triggered by content hash change

## 0.1.6 — Automated patch release triggered by content hash change (2025-12-09)

- chore: Automated patch release triggered by content hash change

## 0.1.4 — Automated patch release triggered by content hash change (2025-12-05)

- chore: Automated patch release triggered by content hash change

## 0.1.3 — Automated patch release triggered by content hash change (2025-12-05)

- chore: Automated patch release triggered by content hash change

## 0.1.2 — Automated patch release triggered by content hash change (2025-12-04)

- chore: Automated patch release triggered by content hash change

## 0.1.1 — Automated patch release triggered by content hash change (2025-12-04)

- chore: Automated patch release triggered by content hash change

## 0.1.0 — Initial baseline (2025-12-04)

- Initial public baseline.
